"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.common.bidding_pb2
import google.ads.google_ads.v4.proto.common.custom_parameter_pb2
import google.ads.google_ads.v4.proto.common.frequency_cap_pb2
import google.ads.google_ads.v4.proto.common.real_time_bidding_setting_pb2
import google.ads.google_ads.v4.proto.common.targeting_setting_pb2
import google.ads.google_ads.v4.proto.enums.ad_serving_optimization_status_pb2
import google.ads.google_ads.v4.proto.enums.advertising_channel_sub_type_pb2
import google.ads.google_ads.v4.proto.enums.advertising_channel_type_pb2
import google.ads.google_ads.v4.proto.enums.app_campaign_app_store_pb2
import google.ads.google_ads.v4.proto.enums.app_campaign_bidding_strategy_goal_type_pb2
import google.ads.google_ads.v4.proto.enums.bidding_strategy_type_pb2
import google.ads.google_ads.v4.proto.enums.brand_safety_suitability_pb2
import google.ads.google_ads.v4.proto.enums.campaign_experiment_type_pb2
import google.ads.google_ads.v4.proto.enums.campaign_serving_status_pb2
import google.ads.google_ads.v4.proto.enums.campaign_status_pb2
import google.ads.google_ads.v4.proto.enums.location_source_type_pb2
import google.ads.google_ads.v4.proto.enums.negative_geo_target_type_pb2
import google.ads.google_ads.v4.proto.enums.optimization_goal_type_pb2
import google.ads.google_ads.v4.proto.enums.payment_mode_pb2
import google.ads.google_ads.v4.proto.enums.positive_geo_target_type_pb2
import google.ads.google_ads.v4.proto.enums.vanity_pharma_display_url_mode_pb2
import google.ads.google_ads.v4.proto.enums.vanity_pharma_text_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Campaign(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class NetworkSettings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        TARGET_GOOGLE_SEARCH_FIELD_NUMBER: builtins.int
        TARGET_SEARCH_NETWORK_FIELD_NUMBER: builtins.int
        TARGET_CONTENT_NETWORK_FIELD_NUMBER: builtins.int
        TARGET_PARTNER_SEARCH_NETWORK_FIELD_NUMBER: builtins.int
        @property
        def target_google_search(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
        @property
        def target_search_network(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
        @property
        def target_content_network(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
        @property
        def target_partner_search_network(
            self,
        ) -> google.protobuf.wrappers_pb2.BoolValue: ...
        def __init__(
            self,
            *,
            target_google_search: typing.Optional[
                google.protobuf.wrappers_pb2.BoolValue
            ] = ...,
            target_search_network: typing.Optional[
                google.protobuf.wrappers_pb2.BoolValue
            ] = ...,
            target_content_network: typing.Optional[
                google.protobuf.wrappers_pb2.BoolValue
            ] = ...,
            target_partner_search_network: typing.Optional[
                google.protobuf.wrappers_pb2.BoolValue
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "target_content_network",
                b"target_content_network",
                "target_google_search",
                b"target_google_search",
                "target_partner_search_network",
                b"target_partner_search_network",
                "target_search_network",
                b"target_search_network",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "target_content_network",
                b"target_content_network",
                "target_google_search",
                b"target_google_search",
                "target_partner_search_network",
                b"target_partner_search_network",
                "target_search_network",
                b"target_search_network",
            ],
        ) -> None: ...
    class HotelSettingInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        HOTEL_CENTER_ID_FIELD_NUMBER: builtins.int
        @property
        def hotel_center_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
        def __init__(
            self,
            *,
            hotel_center_id: typing.Optional[
                google.protobuf.wrappers_pb2.Int64Value
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "hotel_center_id", b"hotel_center_id"
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "hotel_center_id", b"hotel_center_id"
            ],
        ) -> None: ...
    class DynamicSearchAdsSetting(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        DOMAIN_NAME_FIELD_NUMBER: builtins.int
        LANGUAGE_CODE_FIELD_NUMBER: builtins.int
        USE_SUPPLIED_URLS_ONLY_FIELD_NUMBER: builtins.int
        FEEDS_FIELD_NUMBER: builtins.int
        @property
        def domain_name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def language_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def use_supplied_urls_only(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
        @property
        def feeds(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            google.protobuf.wrappers_pb2.StringValue
        ]: ...
        def __init__(
            self,
            *,
            domain_name: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            language_code: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            use_supplied_urls_only: typing.Optional[
                google.protobuf.wrappers_pb2.BoolValue
            ] = ...,
            feeds: typing.Optional[
                typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "domain_name",
                b"domain_name",
                "language_code",
                b"language_code",
                "use_supplied_urls_only",
                b"use_supplied_urls_only",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "domain_name",
                b"domain_name",
                "feeds",
                b"feeds",
                "language_code",
                b"language_code",
                "use_supplied_urls_only",
                b"use_supplied_urls_only",
            ],
        ) -> None: ...
    class SelectiveOptimization(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CONVERSION_ACTIONS_FIELD_NUMBER: builtins.int
        @property
        def conversion_actions(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            google.protobuf.wrappers_pb2.StringValue
        ]: ...
        def __init__(
            self,
            *,
            conversion_actions: typing.Optional[
                typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
            ] = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "conversion_actions", b"conversion_actions"
            ],
        ) -> None: ...
    class ShoppingSetting(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        MERCHANT_ID_FIELD_NUMBER: builtins.int
        SALES_COUNTRY_FIELD_NUMBER: builtins.int
        CAMPAIGN_PRIORITY_FIELD_NUMBER: builtins.int
        ENABLE_LOCAL_FIELD_NUMBER: builtins.int
        @property
        def merchant_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
        @property
        def sales_country(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def campaign_priority(self) -> google.protobuf.wrappers_pb2.Int32Value: ...
        @property
        def enable_local(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
        def __init__(
            self,
            *,
            merchant_id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
            sales_country: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            campaign_priority: typing.Optional[
                google.protobuf.wrappers_pb2.Int32Value
            ] = ...,
            enable_local: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "campaign_priority",
                b"campaign_priority",
                "enable_local",
                b"enable_local",
                "merchant_id",
                b"merchant_id",
                "sales_country",
                b"sales_country",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "campaign_priority",
                b"campaign_priority",
                "enable_local",
                b"enable_local",
                "merchant_id",
                b"merchant_id",
                "sales_country",
                b"sales_country",
            ],
        ) -> None: ...
    class LocalCampaignSetting(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        LOCATION_SOURCE_TYPE_FIELD_NUMBER: builtins.int
        location_source_type: google.ads.google_ads.v4.proto.enums.location_source_type_pb2.LocationSourceTypeEnum.LocationSourceType.V = (
            ...
        )
        def __init__(
            self,
            *,
            location_source_type: google.ads.google_ads.v4.proto.enums.location_source_type_pb2.LocationSourceTypeEnum.LocationSourceType.V = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "location_source_type", b"location_source_type"
            ],
        ) -> None: ...
    class TrackingSetting(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        TRACKING_URL_FIELD_NUMBER: builtins.int
        @property
        def tracking_url(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        def __init__(
            self,
            *,
            tracking_url: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing_extensions.Literal["tracking_url", b"tracking_url"]
        ) -> builtins.bool: ...
        def ClearField(
            self, field_name: typing_extensions.Literal["tracking_url", b"tracking_url"]
        ) -> None: ...
    class GeoTargetTypeSetting(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        POSITIVE_GEO_TARGET_TYPE_FIELD_NUMBER: builtins.int
        NEGATIVE_GEO_TARGET_TYPE_FIELD_NUMBER: builtins.int
        positive_geo_target_type: google.ads.google_ads.v4.proto.enums.positive_geo_target_type_pb2.PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V = (
            ...
        )
        negative_geo_target_type: google.ads.google_ads.v4.proto.enums.negative_geo_target_type_pb2.NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V = (
            ...
        )
        def __init__(
            self,
            *,
            positive_geo_target_type: google.ads.google_ads.v4.proto.enums.positive_geo_target_type_pb2.PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V = ...,
            negative_geo_target_type: google.ads.google_ads.v4.proto.enums.negative_geo_target_type_pb2.NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "negative_geo_target_type",
                b"negative_geo_target_type",
                "positive_geo_target_type",
                b"positive_geo_target_type",
            ],
        ) -> None: ...
    class AppCampaignSetting(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        BIDDING_STRATEGY_GOAL_TYPE_FIELD_NUMBER: builtins.int
        APP_ID_FIELD_NUMBER: builtins.int
        APP_STORE_FIELD_NUMBER: builtins.int
        bidding_strategy_goal_type: google.ads.google_ads.v4.proto.enums.app_campaign_bidding_strategy_goal_type_pb2.AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType.V = (
            ...
        )
        app_store: google.ads.google_ads.v4.proto.enums.app_campaign_app_store_pb2.AppCampaignAppStoreEnum.AppCampaignAppStore.V = (
            ...
        )
        @property
        def app_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        def __init__(
            self,
            *,
            bidding_strategy_goal_type: google.ads.google_ads.v4.proto.enums.app_campaign_bidding_strategy_goal_type_pb2.AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType.V = ...,
            app_id: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
            app_store: google.ads.google_ads.v4.proto.enums.app_campaign_app_store_pb2.AppCampaignAppStoreEnum.AppCampaignAppStore.V = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing_extensions.Literal["app_id", b"app_id"]
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "app_id",
                b"app_id",
                "app_store",
                b"app_store",
                "bidding_strategy_goal_type",
                b"bidding_strategy_goal_type",
            ],
        ) -> None: ...
    class OptimizationGoalSetting(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        OPTIMIZATION_GOAL_TYPES_FIELD_NUMBER: builtins.int
        optimization_goal_types: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
            google.ads.google_ads.v4.proto.enums.optimization_goal_type_pb2.OptimizationGoalTypeEnum.OptimizationGoalType.V
        ] = ...
        def __init__(
            self,
            *,
            optimization_goal_types: typing.Optional[
                typing.Iterable[
                    google.ads.google_ads.v4.proto.enums.optimization_goal_type_pb2.OptimizationGoalTypeEnum.OptimizationGoalType.V
                ]
            ] = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "optimization_goal_types", b"optimization_goal_types"
            ],
        ) -> None: ...
    class VanityPharma(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        VANITY_PHARMA_DISPLAY_URL_MODE_FIELD_NUMBER: builtins.int
        VANITY_PHARMA_TEXT_FIELD_NUMBER: builtins.int
        vanity_pharma_display_url_mode: google.ads.google_ads.v4.proto.enums.vanity_pharma_display_url_mode_pb2.VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlMode.V = (
            ...
        )
        vanity_pharma_text: google.ads.google_ads.v4.proto.enums.vanity_pharma_text_pb2.VanityPharmaTextEnum.VanityPharmaText.V = (
            ...
        )
        def __init__(
            self,
            *,
            vanity_pharma_display_url_mode: google.ads.google_ads.v4.proto.enums.vanity_pharma_display_url_mode_pb2.VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlMode.V = ...,
            vanity_pharma_text: google.ads.google_ads.v4.proto.enums.vanity_pharma_text_pb2.VanityPharmaTextEnum.VanityPharmaText.V = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "vanity_pharma_display_url_mode",
                b"vanity_pharma_display_url_mode",
                "vanity_pharma_text",
                b"vanity_pharma_text",
            ],
        ) -> None: ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SERVING_STATUS_FIELD_NUMBER: builtins.int
    AD_SERVING_OPTIMIZATION_STATUS_FIELD_NUMBER: builtins.int
    ADVERTISING_CHANNEL_TYPE_FIELD_NUMBER: builtins.int
    ADVERTISING_CHANNEL_SUB_TYPE_FIELD_NUMBER: builtins.int
    TRACKING_URL_TEMPLATE_FIELD_NUMBER: builtins.int
    URL_CUSTOM_PARAMETERS_FIELD_NUMBER: builtins.int
    REAL_TIME_BIDDING_SETTING_FIELD_NUMBER: builtins.int
    NETWORK_SETTINGS_FIELD_NUMBER: builtins.int
    HOTEL_SETTING_FIELD_NUMBER: builtins.int
    DYNAMIC_SEARCH_ADS_SETTING_FIELD_NUMBER: builtins.int
    SHOPPING_SETTING_FIELD_NUMBER: builtins.int
    TARGETING_SETTING_FIELD_NUMBER: builtins.int
    GEO_TARGET_TYPE_SETTING_FIELD_NUMBER: builtins.int
    LOCAL_CAMPAIGN_SETTING_FIELD_NUMBER: builtins.int
    APP_CAMPAIGN_SETTING_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    EXPERIMENT_TYPE_FIELD_NUMBER: builtins.int
    BASE_CAMPAIGN_FIELD_NUMBER: builtins.int
    CAMPAIGN_BUDGET_FIELD_NUMBER: builtins.int
    BIDDING_STRATEGY_TYPE_FIELD_NUMBER: builtins.int
    START_DATE_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    FINAL_URL_SUFFIX_FIELD_NUMBER: builtins.int
    FREQUENCY_CAPS_FIELD_NUMBER: builtins.int
    VIDEO_BRAND_SAFETY_SUITABILITY_FIELD_NUMBER: builtins.int
    VANITY_PHARMA_FIELD_NUMBER: builtins.int
    SELECTIVE_OPTIMIZATION_FIELD_NUMBER: builtins.int
    OPTIMIZATION_GOAL_SETTING_FIELD_NUMBER: builtins.int
    TRACKING_SETTING_FIELD_NUMBER: builtins.int
    PAYMENT_MODE_FIELD_NUMBER: builtins.int
    OPTIMIZATION_SCORE_FIELD_NUMBER: builtins.int
    BIDDING_STRATEGY_FIELD_NUMBER: builtins.int
    COMMISSION_FIELD_NUMBER: builtins.int
    MANUAL_CPC_FIELD_NUMBER: builtins.int
    MANUAL_CPM_FIELD_NUMBER: builtins.int
    MANUAL_CPV_FIELD_NUMBER: builtins.int
    MAXIMIZE_CONVERSIONS_FIELD_NUMBER: builtins.int
    MAXIMIZE_CONVERSION_VALUE_FIELD_NUMBER: builtins.int
    TARGET_CPA_FIELD_NUMBER: builtins.int
    TARGET_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    TARGET_ROAS_FIELD_NUMBER: builtins.int
    TARGET_SPEND_FIELD_NUMBER: builtins.int
    PERCENT_CPC_FIELD_NUMBER: builtins.int
    TARGET_CPM_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    status: google.ads.google_ads.v4.proto.enums.campaign_status_pb2.CampaignStatusEnum.CampaignStatus.V = (
        ...
    )
    serving_status: google.ads.google_ads.v4.proto.enums.campaign_serving_status_pb2.CampaignServingStatusEnum.CampaignServingStatus.V = (
        ...
    )
    ad_serving_optimization_status: google.ads.google_ads.v4.proto.enums.ad_serving_optimization_status_pb2.AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V = (
        ...
    )
    advertising_channel_type: google.ads.google_ads.v4.proto.enums.advertising_channel_type_pb2.AdvertisingChannelTypeEnum.AdvertisingChannelType.V = (
        ...
    )
    advertising_channel_sub_type: google.ads.google_ads.v4.proto.enums.advertising_channel_sub_type_pb2.AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V = (
        ...
    )
    experiment_type: google.ads.google_ads.v4.proto.enums.campaign_experiment_type_pb2.CampaignExperimentTypeEnum.CampaignExperimentType.V = (
        ...
    )
    bidding_strategy_type: google.ads.google_ads.v4.proto.enums.bidding_strategy_type_pb2.BiddingStrategyTypeEnum.BiddingStrategyType.V = (
        ...
    )
    video_brand_safety_suitability: google.ads.google_ads.v4.proto.enums.brand_safety_suitability_pb2.BrandSafetySuitabilityEnum.BrandSafetySuitability.V = (
        ...
    )
    payment_mode: google.ads.google_ads.v4.proto.enums.payment_mode_pb2.PaymentModeEnum.PaymentMode.V = (
        ...
    )
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def tracking_url_template(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def url_custom_parameters(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.common.custom_parameter_pb2.CustomParameter
    ]: ...
    @property
    def real_time_bidding_setting(
        self,
    ) -> google.ads.google_ads.v4.proto.common.real_time_bidding_setting_pb2.RealTimeBiddingSetting: ...
    @property
    def network_settings(self) -> global___Campaign.NetworkSettings: ...
    @property
    def hotel_setting(self) -> global___Campaign.HotelSettingInfo: ...
    @property
    def dynamic_search_ads_setting(
        self,
    ) -> global___Campaign.DynamicSearchAdsSetting: ...
    @property
    def shopping_setting(self) -> global___Campaign.ShoppingSetting: ...
    @property
    def targeting_setting(
        self,
    ) -> google.ads.google_ads.v4.proto.common.targeting_setting_pb2.TargetingSetting: ...
    @property
    def geo_target_type_setting(self) -> global___Campaign.GeoTargetTypeSetting: ...
    @property
    def local_campaign_setting(self) -> global___Campaign.LocalCampaignSetting: ...
    @property
    def app_campaign_setting(self) -> global___Campaign.AppCampaignSetting: ...
    @property
    def labels(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def base_campaign(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def campaign_budget(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def start_date(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def end_date(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def final_url_suffix(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def frequency_caps(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.common.frequency_cap_pb2.FrequencyCapEntry
    ]: ...
    @property
    def vanity_pharma(self) -> global___Campaign.VanityPharma: ...
    @property
    def selective_optimization(self) -> global___Campaign.SelectiveOptimization: ...
    @property
    def optimization_goal_setting(
        self,
    ) -> global___Campaign.OptimizationGoalSetting: ...
    @property
    def tracking_setting(self) -> global___Campaign.TrackingSetting: ...
    @property
    def optimization_score(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def bidding_strategy(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def commission(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.Commission: ...
    @property
    def manual_cpc(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.ManualCpc: ...
    @property
    def manual_cpm(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.ManualCpm: ...
    @property
    def manual_cpv(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.ManualCpv: ...
    @property
    def maximize_conversions(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.MaximizeConversions: ...
    @property
    def maximize_conversion_value(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.MaximizeConversionValue: ...
    @property
    def target_cpa(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.TargetCpa: ...
    @property
    def target_impression_share(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.TargetImpressionShare: ...
    @property
    def target_roas(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.TargetRoas: ...
    @property
    def target_spend(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.TargetSpend: ...
    @property
    def percent_cpc(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.PercentCpc: ...
    @property
    def target_cpm(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.TargetCpm: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        status: google.ads.google_ads.v4.proto.enums.campaign_status_pb2.CampaignStatusEnum.CampaignStatus.V = ...,
        serving_status: google.ads.google_ads.v4.proto.enums.campaign_serving_status_pb2.CampaignServingStatusEnum.CampaignServingStatus.V = ...,
        ad_serving_optimization_status: google.ads.google_ads.v4.proto.enums.ad_serving_optimization_status_pb2.AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V = ...,
        advertising_channel_type: google.ads.google_ads.v4.proto.enums.advertising_channel_type_pb2.AdvertisingChannelTypeEnum.AdvertisingChannelType.V = ...,
        advertising_channel_sub_type: google.ads.google_ads.v4.proto.enums.advertising_channel_sub_type_pb2.AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V = ...,
        tracking_url_template: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        url_custom_parameters: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.common.custom_parameter_pb2.CustomParameter
            ]
        ] = ...,
        real_time_bidding_setting: typing.Optional[
            google.ads.google_ads.v4.proto.common.real_time_bidding_setting_pb2.RealTimeBiddingSetting
        ] = ...,
        network_settings: typing.Optional[global___Campaign.NetworkSettings] = ...,
        hotel_setting: typing.Optional[global___Campaign.HotelSettingInfo] = ...,
        dynamic_search_ads_setting: typing.Optional[
            global___Campaign.DynamicSearchAdsSetting
        ] = ...,
        shopping_setting: typing.Optional[global___Campaign.ShoppingSetting] = ...,
        targeting_setting: typing.Optional[
            google.ads.google_ads.v4.proto.common.targeting_setting_pb2.TargetingSetting
        ] = ...,
        geo_target_type_setting: typing.Optional[
            global___Campaign.GeoTargetTypeSetting
        ] = ...,
        local_campaign_setting: typing.Optional[
            global___Campaign.LocalCampaignSetting
        ] = ...,
        app_campaign_setting: typing.Optional[
            global___Campaign.AppCampaignSetting
        ] = ...,
        labels: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        experiment_type: google.ads.google_ads.v4.proto.enums.campaign_experiment_type_pb2.CampaignExperimentTypeEnum.CampaignExperimentType.V = ...,
        base_campaign: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        campaign_budget: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        bidding_strategy_type: google.ads.google_ads.v4.proto.enums.bidding_strategy_type_pb2.BiddingStrategyTypeEnum.BiddingStrategyType.V = ...,
        start_date: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        end_date: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        final_url_suffix: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        frequency_caps: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.common.frequency_cap_pb2.FrequencyCapEntry
            ]
        ] = ...,
        video_brand_safety_suitability: google.ads.google_ads.v4.proto.enums.brand_safety_suitability_pb2.BrandSafetySuitabilityEnum.BrandSafetySuitability.V = ...,
        vanity_pharma: typing.Optional[global___Campaign.VanityPharma] = ...,
        selective_optimization: typing.Optional[
            global___Campaign.SelectiveOptimization
        ] = ...,
        optimization_goal_setting: typing.Optional[
            global___Campaign.OptimizationGoalSetting
        ] = ...,
        tracking_setting: typing.Optional[global___Campaign.TrackingSetting] = ...,
        payment_mode: google.ads.google_ads.v4.proto.enums.payment_mode_pb2.PaymentModeEnum.PaymentMode.V = ...,
        optimization_score: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        bidding_strategy: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        commission: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.Commission
        ] = ...,
        manual_cpc: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.ManualCpc
        ] = ...,
        manual_cpm: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.ManualCpm
        ] = ...,
        manual_cpv: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.ManualCpv
        ] = ...,
        maximize_conversions: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.MaximizeConversions
        ] = ...,
        maximize_conversion_value: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.MaximizeConversionValue
        ] = ...,
        target_cpa: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.TargetCpa
        ] = ...,
        target_impression_share: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.TargetImpressionShare
        ] = ...,
        target_roas: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.TargetRoas
        ] = ...,
        target_spend: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.TargetSpend
        ] = ...,
        percent_cpc: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.PercentCpc
        ] = ...,
        target_cpm: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.TargetCpm
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "app_campaign_setting",
            b"app_campaign_setting",
            "base_campaign",
            b"base_campaign",
            "bidding_strategy",
            b"bidding_strategy",
            "campaign_bidding_strategy",
            b"campaign_bidding_strategy",
            "campaign_budget",
            b"campaign_budget",
            "commission",
            b"commission",
            "dynamic_search_ads_setting",
            b"dynamic_search_ads_setting",
            "end_date",
            b"end_date",
            "final_url_suffix",
            b"final_url_suffix",
            "geo_target_type_setting",
            b"geo_target_type_setting",
            "hotel_setting",
            b"hotel_setting",
            "id",
            b"id",
            "local_campaign_setting",
            b"local_campaign_setting",
            "manual_cpc",
            b"manual_cpc",
            "manual_cpm",
            b"manual_cpm",
            "manual_cpv",
            b"manual_cpv",
            "maximize_conversion_value",
            b"maximize_conversion_value",
            "maximize_conversions",
            b"maximize_conversions",
            "name",
            b"name",
            "network_settings",
            b"network_settings",
            "optimization_goal_setting",
            b"optimization_goal_setting",
            "optimization_score",
            b"optimization_score",
            "percent_cpc",
            b"percent_cpc",
            "real_time_bidding_setting",
            b"real_time_bidding_setting",
            "selective_optimization",
            b"selective_optimization",
            "shopping_setting",
            b"shopping_setting",
            "start_date",
            b"start_date",
            "target_cpa",
            b"target_cpa",
            "target_cpm",
            b"target_cpm",
            "target_impression_share",
            b"target_impression_share",
            "target_roas",
            b"target_roas",
            "target_spend",
            b"target_spend",
            "targeting_setting",
            b"targeting_setting",
            "tracking_setting",
            b"tracking_setting",
            "tracking_url_template",
            b"tracking_url_template",
            "vanity_pharma",
            b"vanity_pharma",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ad_serving_optimization_status",
            b"ad_serving_optimization_status",
            "advertising_channel_sub_type",
            b"advertising_channel_sub_type",
            "advertising_channel_type",
            b"advertising_channel_type",
            "app_campaign_setting",
            b"app_campaign_setting",
            "base_campaign",
            b"base_campaign",
            "bidding_strategy",
            b"bidding_strategy",
            "bidding_strategy_type",
            b"bidding_strategy_type",
            "campaign_bidding_strategy",
            b"campaign_bidding_strategy",
            "campaign_budget",
            b"campaign_budget",
            "commission",
            b"commission",
            "dynamic_search_ads_setting",
            b"dynamic_search_ads_setting",
            "end_date",
            b"end_date",
            "experiment_type",
            b"experiment_type",
            "final_url_suffix",
            b"final_url_suffix",
            "frequency_caps",
            b"frequency_caps",
            "geo_target_type_setting",
            b"geo_target_type_setting",
            "hotel_setting",
            b"hotel_setting",
            "id",
            b"id",
            "labels",
            b"labels",
            "local_campaign_setting",
            b"local_campaign_setting",
            "manual_cpc",
            b"manual_cpc",
            "manual_cpm",
            b"manual_cpm",
            "manual_cpv",
            b"manual_cpv",
            "maximize_conversion_value",
            b"maximize_conversion_value",
            "maximize_conversions",
            b"maximize_conversions",
            "name",
            b"name",
            "network_settings",
            b"network_settings",
            "optimization_goal_setting",
            b"optimization_goal_setting",
            "optimization_score",
            b"optimization_score",
            "payment_mode",
            b"payment_mode",
            "percent_cpc",
            b"percent_cpc",
            "real_time_bidding_setting",
            b"real_time_bidding_setting",
            "resource_name",
            b"resource_name",
            "selective_optimization",
            b"selective_optimization",
            "serving_status",
            b"serving_status",
            "shopping_setting",
            b"shopping_setting",
            "start_date",
            b"start_date",
            "status",
            b"status",
            "target_cpa",
            b"target_cpa",
            "target_cpm",
            b"target_cpm",
            "target_impression_share",
            b"target_impression_share",
            "target_roas",
            b"target_roas",
            "target_spend",
            b"target_spend",
            "targeting_setting",
            b"targeting_setting",
            "tracking_setting",
            b"tracking_setting",
            "tracking_url_template",
            b"tracking_url_template",
            "url_custom_parameters",
            b"url_custom_parameters",
            "vanity_pharma",
            b"vanity_pharma",
            "video_brand_safety_suitability",
            b"video_brand_safety_suitability",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "campaign_bidding_strategy", b"campaign_bidding_strategy"
        ],
    ) -> typing_extensions.Literal[
        "bidding_strategy",
        "commission",
        "manual_cpc",
        "manual_cpm",
        "manual_cpv",
        "maximize_conversions",
        "maximize_conversion_value",
        "target_cpa",
        "target_impression_share",
        "target_roas",
        "target_spend",
        "percent_cpc",
        "target_cpm",
    ]: ...

global___Campaign = Campaign



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Value(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BOOLEAN_VALUE_FIELD_NUMBER: builtins.int
    INT64_VALUE_FIELD_NUMBER: builtins.int
    FLOAT_VALUE_FIELD_NUMBER: builtins.int
    DOUBLE_VALUE_FIELD_NUMBER: builtins.int
    STRING_VALUE_FIELD_NUMBER: builtins.int
    boolean_value: builtins.bool = ...
    int64_value: builtins.int = ...
    float_value: builtins.float = ...
    double_value: builtins.float = ...
    string_value: typing.Text = ...
    def __init__(
        self,
        *,
        boolean_value: builtins.bool = ...,
        int64_value: builtins.int = ...,
        float_value: builtins.float = ...,
        double_value: builtins.float = ...,
        string_value: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "boolean_value",
            b"boolean_value",
            "double_value",
            b"double_value",
            "float_value",
            b"float_value",
            "int64_value",
            b"int64_value",
            "string_value",
            b"string_value",
            "value",
            b"value",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "boolean_value",
            b"boolean_value",
            "double_value",
            b"double_value",
            "float_value",
            b"float_value",
            "int64_value",
            b"int64_value",
            "string_value",
            b"string_value",
            "value",
            b"value",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["value", b"value"]
    ) -> typing_extensions.Literal[
        "boolean_value", "int64_value", "float_value", "double_value", "string_value"
    ]: ...

global___Value = Value



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class OfflineUserDataJobErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _OfflineUserDataJobError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            OfflineUserDataJobError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(0)
        UNKNOWN = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(1)
        INVALID_USER_LIST_ID = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(3)
        INVALID_USER_LIST_TYPE = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(
            4
        )
        NOT_ON_ALLOWLIST_FOR_USER_ID = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(33)
        )
        INCOMPATIBLE_UPLOAD_KEY_TYPE = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(6)
        )
        MISSING_USER_IDENTIFIER = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(
            7
        )
        INVALID_MOBILE_ID_FORMAT = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(8)
        )
        TOO_MANY_USER_IDENTIFIERS = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(9)
        )
        NOT_ON_ALLOWLIST_FOR_STORE_SALES_DIRECT = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(31)
        )
        NOT_ON_ALLOWLIST_FOR_UNIFIED_STORE_SALES = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(32)
        )
        INVALID_PARTNER_ID = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(11)
        INVALID_ENCODING = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(12)
        INVALID_COUNTRY_CODE = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(13)
        INCOMPATIBLE_USER_IDENTIFIER = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(14)
        )
        FUTURE_TRANSACTION_TIME = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(
            15
        )
        INVALID_CONVERSION_ACTION = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(16)
        )
        MOBILE_ID_NOT_SUPPORTED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(
            17
        )
        INVALID_OPERATION_ORDER = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(
            18
        )
        CONFLICTING_OPERATION = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(
            19
        )
        EXTERNAL_UPDATE_ID_ALREADY_EXISTS = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(21)
        )
        JOB_ALREADY_STARTED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(22)
        REMOVE_NOT_SUPPORTED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(23)
        REMOVE_ALL_NOT_SUPPORTED = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(24)
        )
        INVALID_SHA256_FORMAT = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(
            25
        )
        CUSTOM_KEY_DISABLED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(26)
        CUSTOM_KEY_NOT_PREDEFINED = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(27)
        )
        CUSTOM_KEY_NOT_SET = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(29)
        CUSTOMER_NOT_ACCEPTED_CUSTOMER_DATA_TERMS = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(30)
        )
        ATTRIBUTES_NOT_APPLICABLE_FOR_CUSTOMER_MATCH_USER_LIST = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(34)
        )
        LIFETIME_VALUE_BUCKET_NOT_IN_RANGE = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(35)
        )
        INCOMPATIBLE_USER_IDENTIFIER_FOR_ATTRIBUTES = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(36)
        )
    class OfflineUserDataJobError(metaclass=_OfflineUserDataJobError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(0)
    UNKNOWN = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(1)
    INVALID_USER_LIST_ID = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(3)
    INVALID_USER_LIST_TYPE = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(4)
    NOT_ON_ALLOWLIST_FOR_USER_ID = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(33)
    )
    INCOMPATIBLE_UPLOAD_KEY_TYPE = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(6)
    )
    MISSING_USER_IDENTIFIER = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(7)
    INVALID_MOBILE_ID_FORMAT = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(8)
    TOO_MANY_USER_IDENTIFIERS = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(9)
    NOT_ON_ALLOWLIST_FOR_STORE_SALES_DIRECT = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(31)
    )
    NOT_ON_ALLOWLIST_FOR_UNIFIED_STORE_SALES = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(32)
    )
    INVALID_PARTNER_ID = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(11)
    INVALID_ENCODING = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(12)
    INVALID_COUNTRY_CODE = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(13)
    INCOMPATIBLE_USER_IDENTIFIER = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(14)
    )
    FUTURE_TRANSACTION_TIME = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(15)
    INVALID_CONVERSION_ACTION = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(
        16
    )
    MOBILE_ID_NOT_SUPPORTED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(17)
    INVALID_OPERATION_ORDER = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(18)
    CONFLICTING_OPERATION = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(19)
    EXTERNAL_UPDATE_ID_ALREADY_EXISTS = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(21)
    )
    JOB_ALREADY_STARTED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(22)
    REMOVE_NOT_SUPPORTED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(23)
    REMOVE_ALL_NOT_SUPPORTED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(24)
    INVALID_SHA256_FORMAT = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(25)
    CUSTOM_KEY_DISABLED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(26)
    CUSTOM_KEY_NOT_PREDEFINED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(
        27
    )
    CUSTOM_KEY_NOT_SET = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(29)
    CUSTOMER_NOT_ACCEPTED_CUSTOMER_DATA_TERMS = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(30)
    )
    ATTRIBUTES_NOT_APPLICABLE_FOR_CUSTOMER_MATCH_USER_LIST = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(34)
    )
    LIFETIME_VALUE_BUCKET_NOT_IN_RANGE = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(35)
    )
    INCOMPATIBLE_USER_IDENTIFIER_FOR_ATTRIBUTES = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(36)
    )
    def __init__(
        self,
    ) -> None: ...

global___OfflineUserDataJobErrorEnum = OfflineUserDataJobErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.resources.ad_pb2
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GetAdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetAdRequest = GetAdRequest

class MutateAdsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    OPERATIONS_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    @property
    def operations(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___AdOperation
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        operations: typing.Optional[typing.Iterable[global___AdOperation]] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id", b"customer_id", "operations", b"operations"
        ],
    ) -> None: ...

global___MutateAdsRequest = MutateAdsRequest

class AdOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def update(self) -> google.ads.google_ads.v4.proto.resources.ad_pb2.Ad: ...
    def __init__(
        self,
        *,
        update_mask: typing.Optional[google.protobuf.field_mask_pb2.FieldMask] = ...,
        update: typing.Optional[
            google.ads.google_ads.v4.proto.resources.ad_pb2.Ad
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "operation",
            b"operation",
            "update",
            b"update",
            "update_mask",
            b"update_mask",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "operation",
            b"operation",
            "update",
            b"update",
            "update_mask",
            b"update_mask",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["operation", b"operation"]
    ) -> typing_extensions.Literal["update"]: ...

global___AdOperation = AdOperation

class MutateAdsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULTS_FIELD_NUMBER: builtins.int
    @property
    def results(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___MutateAdResult
    ]: ...
    def __init__(
        self,
        *,
        results: typing.Optional[typing.Iterable[global___MutateAdResult]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["results", b"results"]
    ) -> None: ...

global___MutateAdsResponse = MutateAdsResponse

class MutateAdResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___MutateAdResult = MutateAdResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.campaign_budget_pb2
import grpc

from .campaign_budget_service_pb2 import *

class CampaignBudgetServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaignBudget(
        self,
        request: global___GetCampaignBudgetRequest,
    ) -> google.ads.google_ads.v5.proto.resources.campaign_budget_pb2.CampaignBudget: ...
    def MutateCampaignBudgets(
        self,
        request: global___MutateCampaignBudgetsRequest,
    ) -> global___MutateCampaignBudgetsResponse: ...

class CampaignBudgetServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaignBudget(
        self,
        request: global___GetCampaignBudgetRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.campaign_budget_pb2.CampaignBudget: ...
    @abc.abstractmethod
    def MutateCampaignBudgets(
        self,
        request: global___MutateCampaignBudgetsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignBudgetsResponse: ...

def add_CampaignBudgetServiceServicer_to_server(
    servicer: CampaignBudgetServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.campaign_bid_modifier_pb2
import grpc

from .campaign_bid_modifier_service_pb2 import *

class CampaignBidModifierServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaignBidModifier(
        self,
        request: global___GetCampaignBidModifierRequest,
    ) -> google.ads.google_ads.v6.proto.resources.campaign_bid_modifier_pb2.CampaignBidModifier: ...
    def MutateCampaignBidModifiers(
        self,
        request: global___MutateCampaignBidModifiersRequest,
    ) -> global___MutateCampaignBidModifiersResponse: ...

class CampaignBidModifierServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaignBidModifier(
        self,
        request: global___GetCampaignBidModifierRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.campaign_bid_modifier_pb2.CampaignBidModifier: ...
    @abc.abstractmethod
    def MutateCampaignBidModifiers(
        self,
        request: global___MutateCampaignBidModifiersRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignBidModifiersResponse: ...

def add_CampaignBidModifierServiceServicer_to_server(
    servicer: CampaignBidModifierServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ThirdPartyAppAnalyticsLinkErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ThirdPartyAppAnalyticsLinkError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ThirdPartyAppAnalyticsLinkError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(0)
        )
        UNKNOWN = ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(
            1
        )
        INVALID_ANALYTICS_PROVIDER_ID = (
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(2)
        )
        INVALID_MOBILE_APP_ID = (
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(3)
        )
        MOBILE_APP_IS_NOT_ENABLED = (
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(4)
        )
        CANNOT_REGENERATE_SHAREABLE_LINK_ID_FOR_REMOVED_LINK = (
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(5)
        )
    class ThirdPartyAppAnalyticsLinkError(metaclass=_ThirdPartyAppAnalyticsLinkError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(
        0
    )
    UNKNOWN = ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(1)
    INVALID_ANALYTICS_PROVIDER_ID = (
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(2)
    )
    INVALID_MOBILE_APP_ID = (
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(3)
    )
    MOBILE_APP_IS_NOT_ENABLED = (
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(4)
    )
    CANNOT_REGENERATE_SHAREABLE_LINK_ID_FOR_REMOVED_LINK = (
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(5)
    )
    def __init__(
        self,
    ) -> None: ...

global___ThirdPartyAppAnalyticsLinkErrorEnum = ThirdPartyAppAnalyticsLinkErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.common.keyword_plan_common_pb2
import google.ads.google_ads.v6.proto.resources.keyword_plan_pb2
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.rpc.status_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GetKeywordPlanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetKeywordPlanRequest = GetKeywordPlanRequest

class MutateKeywordPlansRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    OPERATIONS_FIELD_NUMBER: builtins.int
    PARTIAL_FAILURE_FIELD_NUMBER: builtins.int
    VALIDATE_ONLY_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    partial_failure: builtins.bool = ...
    validate_only: builtins.bool = ...
    @property
    def operations(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___KeywordPlanOperation
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        operations: typing.Optional[
            typing.Iterable[global___KeywordPlanOperation]
        ] = ...,
        partial_failure: builtins.bool = ...,
        validate_only: builtins.bool = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id",
            b"customer_id",
            "operations",
            b"operations",
            "partial_failure",
            b"partial_failure",
            "validate_only",
            b"validate_only",
        ],
    ) -> None: ...

global___MutateKeywordPlansRequest = MutateKeywordPlansRequest

class KeywordPlanOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    CREATE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    REMOVE_FIELD_NUMBER: builtins.int
    remove: typing.Text = ...
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def create(
        self,
    ) -> google.ads.google_ads.v6.proto.resources.keyword_plan_pb2.KeywordPlan: ...
    @property
    def update(
        self,
    ) -> google.ads.google_ads.v6.proto.resources.keyword_plan_pb2.KeywordPlan: ...
    def __init__(
        self,
        *,
        update_mask: typing.Optional[google.protobuf.field_mask_pb2.FieldMask] = ...,
        create: typing.Optional[
            google.ads.google_ads.v6.proto.resources.keyword_plan_pb2.KeywordPlan
        ] = ...,
        update: typing.Optional[
            google.ads.google_ads.v6.proto.resources.keyword_plan_pb2.KeywordPlan
        ] = ...,
        remove: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "create",
            b"create",
            "operation",
            b"operation",
            "remove",
            b"remove",
            "update",
            b"update",
            "update_mask",
            b"update_mask",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "create",
            b"create",
            "operation",
            b"operation",
            "remove",
            b"remove",
            "update",
            b"update",
            "update_mask",
            b"update_mask",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["operation", b"operation"]
    ) -> typing_extensions.Literal["create", "update", "remove"]: ...

global___KeywordPlanOperation = KeywordPlanOperation

class MutateKeywordPlansResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARTIAL_FAILURE_ERROR_FIELD_NUMBER: builtins.int
    RESULTS_FIELD_NUMBER: builtins.int
    @property
    def partial_failure_error(self) -> google.rpc.status_pb2.Status: ...
    @property
    def results(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___MutateKeywordPlansResult
    ]: ...
    def __init__(
        self,
        *,
        partial_failure_error: typing.Optional[google.rpc.status_pb2.Status] = ...,
        results: typing.Optional[
            typing.Iterable[global___MutateKeywordPlansResult]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "partial_failure_error", b"partial_failure_error", "results", b"results"
        ],
    ) -> None: ...

global___MutateKeywordPlansResponse = MutateKeywordPlansResponse

class MutateKeywordPlansResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___MutateKeywordPlansResult = MutateKeywordPlansResult

class GenerateForecastCurveRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEYWORD_PLAN_FIELD_NUMBER: builtins.int
    keyword_plan: typing.Text = ...
    def __init__(
        self,
        *,
        keyword_plan: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["keyword_plan", b"keyword_plan"]
    ) -> None: ...

global___GenerateForecastCurveRequest = GenerateForecastCurveRequest

class GenerateForecastCurveResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CAMPAIGN_FORECAST_CURVES_FIELD_NUMBER: builtins.int
    @property
    def campaign_forecast_curves(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___KeywordPlanCampaignForecastCurve
    ]: ...
    def __init__(
        self,
        *,
        campaign_forecast_curves: typing.Optional[
            typing.Iterable[global___KeywordPlanCampaignForecastCurve]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "campaign_forecast_curves", b"campaign_forecast_curves"
        ],
    ) -> None: ...

global___GenerateForecastCurveResponse = GenerateForecastCurveResponse

class GenerateForecastTimeSeriesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEYWORD_PLAN_FIELD_NUMBER: builtins.int
    keyword_plan: typing.Text = ...
    def __init__(
        self,
        *,
        keyword_plan: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["keyword_plan", b"keyword_plan"]
    ) -> None: ...

global___GenerateForecastTimeSeriesRequest = GenerateForecastTimeSeriesRequest

class GenerateForecastTimeSeriesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    WEEKLY_TIME_SERIES_FORECASTS_FIELD_NUMBER: builtins.int
    @property
    def weekly_time_series_forecasts(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___KeywordPlanWeeklyTimeSeriesForecast
    ]: ...
    def __init__(
        self,
        *,
        weekly_time_series_forecasts: typing.Optional[
            typing.Iterable[global___KeywordPlanWeeklyTimeSeriesForecast]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "weekly_time_series_forecasts", b"weekly_time_series_forecasts"
        ],
    ) -> None: ...

global___GenerateForecastTimeSeriesResponse = GenerateForecastTimeSeriesResponse

class GenerateForecastMetricsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEYWORD_PLAN_FIELD_NUMBER: builtins.int
    keyword_plan: typing.Text = ...
    def __init__(
        self,
        *,
        keyword_plan: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["keyword_plan", b"keyword_plan"]
    ) -> None: ...

global___GenerateForecastMetricsRequest = GenerateForecastMetricsRequest

class GenerateForecastMetricsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CAMPAIGN_FORECASTS_FIELD_NUMBER: builtins.int
    AD_GROUP_FORECASTS_FIELD_NUMBER: builtins.int
    KEYWORD_FORECASTS_FIELD_NUMBER: builtins.int
    @property
    def campaign_forecasts(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___KeywordPlanCampaignForecast
    ]: ...
    @property
    def ad_group_forecasts(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___KeywordPlanAdGroupForecast
    ]: ...
    @property
    def keyword_forecasts(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___KeywordPlanKeywordForecast
    ]: ...
    def __init__(
        self,
        *,
        campaign_forecasts: typing.Optional[
            typing.Iterable[global___KeywordPlanCampaignForecast]
        ] = ...,
        ad_group_forecasts: typing.Optional[
            typing.Iterable[global___KeywordPlanAdGroupForecast]
        ] = ...,
        keyword_forecasts: typing.Optional[
            typing.Iterable[global___KeywordPlanKeywordForecast]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ad_group_forecasts",
            b"ad_group_forecasts",
            "campaign_forecasts",
            b"campaign_forecasts",
            "keyword_forecasts",
            b"keyword_forecasts",
        ],
    ) -> None: ...

global___GenerateForecastMetricsResponse = GenerateForecastMetricsResponse

class KeywordPlanCampaignForecast(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEYWORD_PLAN_CAMPAIGN_FIELD_NUMBER: builtins.int
    CAMPAIGN_FORECAST_FIELD_NUMBER: builtins.int
    keyword_plan_campaign: typing.Text = ...
    @property
    def campaign_forecast(self) -> global___ForecastMetrics: ...
    def __init__(
        self,
        *,
        keyword_plan_campaign: typing.Text = ...,
        campaign_forecast: typing.Optional[global___ForecastMetrics] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_keyword_plan_campaign",
            b"_keyword_plan_campaign",
            "campaign_forecast",
            b"campaign_forecast",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_keyword_plan_campaign",
            b"_keyword_plan_campaign",
            "campaign_forecast",
            b"campaign_forecast",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_keyword_plan_campaign", b"_keyword_plan_campaign"
        ],
    ) -> typing_extensions.Literal["keyword_plan_campaign"]: ...

global___KeywordPlanCampaignForecast = KeywordPlanCampaignForecast

class KeywordPlanAdGroupForecast(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEYWORD_PLAN_AD_GROUP_FIELD_NUMBER: builtins.int
    AD_GROUP_FORECAST_FIELD_NUMBER: builtins.int
    keyword_plan_ad_group: typing.Text = ...
    @property
    def ad_group_forecast(self) -> global___ForecastMetrics: ...
    def __init__(
        self,
        *,
        keyword_plan_ad_group: typing.Text = ...,
        ad_group_forecast: typing.Optional[global___ForecastMetrics] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_keyword_plan_ad_group",
            b"_keyword_plan_ad_group",
            "ad_group_forecast",
            b"ad_group_forecast",
            "keyword_plan_ad_group",
            b"keyword_plan_ad_group",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_keyword_plan_ad_group",
            b"_keyword_plan_ad_group",
            "ad_group_forecast",
            b"ad_group_forecast",
            "keyword_plan_ad_group",
            b"keyword_plan_ad_group",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_keyword_plan_ad_group", b"_keyword_plan_ad_group"
        ],
    ) -> typing_extensions.Literal["keyword_plan_ad_group"]: ...

global___KeywordPlanAdGroupForecast = KeywordPlanAdGroupForecast

class KeywordPlanKeywordForecast(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEYWORD_PLAN_AD_GROUP_KEYWORD_FIELD_NUMBER: builtins.int
    KEYWORD_FORECAST_FIELD_NUMBER: builtins.int
    keyword_plan_ad_group_keyword: typing.Text = ...
    @property
    def keyword_forecast(self) -> global___ForecastMetrics: ...
    def __init__(
        self,
        *,
        keyword_plan_ad_group_keyword: typing.Text = ...,
        keyword_forecast: typing.Optional[global___ForecastMetrics] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_keyword_plan_ad_group_keyword",
            b"_keyword_plan_ad_group_keyword",
            "keyword_forecast",
            b"keyword_forecast",
            "keyword_plan_ad_group_keyword",
            b"keyword_plan_ad_group_keyword",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_keyword_plan_ad_group_keyword",
            b"_keyword_plan_ad_group_keyword",
            "keyword_forecast",
            b"keyword_forecast",
            "keyword_plan_ad_group_keyword",
            b"keyword_plan_ad_group_keyword",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_keyword_plan_ad_group_keyword", b"_keyword_plan_ad_group_keyword"
        ],
    ) -> typing_extensions.Literal["keyword_plan_ad_group_keyword"]: ...

global___KeywordPlanKeywordForecast = KeywordPlanKeywordForecast

class KeywordPlanCampaignForecastCurve(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEYWORD_PLAN_CAMPAIGN_FIELD_NUMBER: builtins.int
    MAX_CPC_BID_FORECAST_CURVE_FIELD_NUMBER: builtins.int
    keyword_plan_campaign: typing.Text = ...
    @property
    def max_cpc_bid_forecast_curve(
        self,
    ) -> global___KeywordPlanMaxCpcBidForecastCurve: ...
    def __init__(
        self,
        *,
        keyword_plan_campaign: typing.Text = ...,
        max_cpc_bid_forecast_curve: typing.Optional[
            global___KeywordPlanMaxCpcBidForecastCurve
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_keyword_plan_campaign",
            b"_keyword_plan_campaign",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
            "max_cpc_bid_forecast_curve",
            b"max_cpc_bid_forecast_curve",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_keyword_plan_campaign",
            b"_keyword_plan_campaign",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
            "max_cpc_bid_forecast_curve",
            b"max_cpc_bid_forecast_curve",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_keyword_plan_campaign", b"_keyword_plan_campaign"
        ],
    ) -> typing_extensions.Literal["keyword_plan_campaign"]: ...

global___KeywordPlanCampaignForecastCurve = KeywordPlanCampaignForecastCurve

class KeywordPlanMaxCpcBidForecastCurve(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MAX_CPC_BID_FORECASTS_FIELD_NUMBER: builtins.int
    @property
    def max_cpc_bid_forecasts(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___KeywordPlanMaxCpcBidForecast
    ]: ...
    def __init__(
        self,
        *,
        max_cpc_bid_forecasts: typing.Optional[
            typing.Iterable[global___KeywordPlanMaxCpcBidForecast]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "max_cpc_bid_forecasts", b"max_cpc_bid_forecasts"
        ],
    ) -> None: ...

global___KeywordPlanMaxCpcBidForecastCurve = KeywordPlanMaxCpcBidForecastCurve

class KeywordPlanMaxCpcBidForecast(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MAX_CPC_BID_MICROS_FIELD_NUMBER: builtins.int
    MAX_CPC_BID_FORECAST_FIELD_NUMBER: builtins.int
    max_cpc_bid_micros: builtins.int = ...
    @property
    def max_cpc_bid_forecast(self) -> global___ForecastMetrics: ...
    def __init__(
        self,
        *,
        max_cpc_bid_micros: builtins.int = ...,
        max_cpc_bid_forecast: typing.Optional[global___ForecastMetrics] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_max_cpc_bid_micros",
            b"_max_cpc_bid_micros",
            "max_cpc_bid_forecast",
            b"max_cpc_bid_forecast",
            "max_cpc_bid_micros",
            b"max_cpc_bid_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_max_cpc_bid_micros",
            b"_max_cpc_bid_micros",
            "max_cpc_bid_forecast",
            b"max_cpc_bid_forecast",
            "max_cpc_bid_micros",
            b"max_cpc_bid_micros",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_max_cpc_bid_micros", b"_max_cpc_bid_micros"
        ],
    ) -> typing_extensions.Literal["max_cpc_bid_micros"]: ...

global___KeywordPlanMaxCpcBidForecast = KeywordPlanMaxCpcBidForecast

class KeywordPlanWeeklyTimeSeriesForecast(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEYWORD_PLAN_CAMPAIGN_FIELD_NUMBER: builtins.int
    WEEKLY_FORECASTS_FIELD_NUMBER: builtins.int
    keyword_plan_campaign: typing.Text = ...
    @property
    def weekly_forecasts(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___KeywordPlanWeeklyForecast
    ]: ...
    def __init__(
        self,
        *,
        keyword_plan_campaign: typing.Text = ...,
        weekly_forecasts: typing.Optional[
            typing.Iterable[global___KeywordPlanWeeklyForecast]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_keyword_plan_campaign",
            b"_keyword_plan_campaign",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_keyword_plan_campaign",
            b"_keyword_plan_campaign",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
            "weekly_forecasts",
            b"weekly_forecasts",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_keyword_plan_campaign", b"_keyword_plan_campaign"
        ],
    ) -> typing_extensions.Literal["keyword_plan_campaign"]: ...

global___KeywordPlanWeeklyTimeSeriesForecast = KeywordPlanWeeklyTimeSeriesForecast

class KeywordPlanWeeklyForecast(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    START_DATE_FIELD_NUMBER: builtins.int
    FORECAST_FIELD_NUMBER: builtins.int
    start_date: typing.Text = ...
    @property
    def forecast(self) -> global___ForecastMetrics: ...
    def __init__(
        self,
        *,
        start_date: typing.Text = ...,
        forecast: typing.Optional[global___ForecastMetrics] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_start_date",
            b"_start_date",
            "forecast",
            b"forecast",
            "start_date",
            b"start_date",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_start_date",
            b"_start_date",
            "forecast",
            b"forecast",
            "start_date",
            b"start_date",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_start_date", b"_start_date"]
    ) -> typing_extensions.Literal["start_date"]: ...

global___KeywordPlanWeeklyForecast = KeywordPlanWeeklyForecast

class ForecastMetrics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    CTR_FIELD_NUMBER: builtins.int
    AVERAGE_CPC_FIELD_NUMBER: builtins.int
    CLICKS_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    impressions: builtins.float = ...
    ctr: builtins.float = ...
    average_cpc: builtins.int = ...
    clicks: builtins.float = ...
    cost_micros: builtins.int = ...
    def __init__(
        self,
        *,
        impressions: builtins.float = ...,
        ctr: builtins.float = ...,
        average_cpc: builtins.int = ...,
        clicks: builtins.float = ...,
        cost_micros: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_average_cpc",
            b"_average_cpc",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_ctr",
            b"_ctr",
            "_impressions",
            b"_impressions",
            "average_cpc",
            b"average_cpc",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "ctr",
            b"ctr",
            "impressions",
            b"impressions",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_average_cpc",
            b"_average_cpc",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_ctr",
            b"_ctr",
            "_impressions",
            b"_impressions",
            "average_cpc",
            b"average_cpc",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "ctr",
            b"ctr",
            "impressions",
            b"impressions",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_average_cpc", b"_average_cpc"]
    ) -> typing_extensions.Literal["average_cpc"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_clicks", b"_clicks"]
    ) -> typing_extensions.Literal["clicks"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions.Literal["cost_micros"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_ctr", b"_ctr"]
    ) -> typing_extensions.Literal["ctr"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_impressions", b"_impressions"]
    ) -> typing_extensions.Literal["impressions"]: ...

global___ForecastMetrics = ForecastMetrics

class GenerateHistoricalMetricsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEYWORD_PLAN_FIELD_NUMBER: builtins.int
    keyword_plan: typing.Text = ...
    def __init__(
        self,
        *,
        keyword_plan: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["keyword_plan", b"keyword_plan"]
    ) -> None: ...

global___GenerateHistoricalMetricsRequest = GenerateHistoricalMetricsRequest

class GenerateHistoricalMetricsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    METRICS_FIELD_NUMBER: builtins.int
    @property
    def metrics(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___KeywordPlanKeywordHistoricalMetrics
    ]: ...
    def __init__(
        self,
        *,
        metrics: typing.Optional[
            typing.Iterable[global___KeywordPlanKeywordHistoricalMetrics]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["metrics", b"metrics"]
    ) -> None: ...

global___GenerateHistoricalMetricsResponse = GenerateHistoricalMetricsResponse

class KeywordPlanKeywordHistoricalMetrics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SEARCH_QUERY_FIELD_NUMBER: builtins.int
    CLOSE_VARIANTS_FIELD_NUMBER: builtins.int
    KEYWORD_METRICS_FIELD_NUMBER: builtins.int
    search_query: typing.Text = ...
    close_variants: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    @property
    def keyword_metrics(
        self,
    ) -> google.ads.google_ads.v6.proto.common.keyword_plan_common_pb2.KeywordPlanHistoricalMetrics: ...
    def __init__(
        self,
        *,
        search_query: typing.Text = ...,
        close_variants: typing.Optional[typing.Iterable[typing.Text]] = ...,
        keyword_metrics: typing.Optional[
            google.ads.google_ads.v6.proto.common.keyword_plan_common_pb2.KeywordPlanHistoricalMetrics
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_search_query",
            b"_search_query",
            "keyword_metrics",
            b"keyword_metrics",
            "search_query",
            b"search_query",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_search_query",
            b"_search_query",
            "close_variants",
            b"close_variants",
            "keyword_metrics",
            b"keyword_metrics",
            "search_query",
            b"search_query",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_search_query", b"_search_query"]
    ) -> typing_extensions.Literal["search_query"]: ...

global___KeywordPlanKeywordHistoricalMetrics = KeywordPlanKeywordHistoricalMetrics



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .reach_plan_service_pb2 import *

class ReachPlanServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def ListPlannableLocations(
        self,
        request: global___ListPlannableLocationsRequest,
    ) -> global___ListPlannableLocationsResponse: ...
    def ListPlannableProducts(
        self,
        request: global___ListPlannableProductsRequest,
    ) -> global___ListPlannableProductsResponse: ...
    def GenerateProductMixIdeas(
        self,
        request: global___GenerateProductMixIdeasRequest,
    ) -> global___GenerateProductMixIdeasResponse: ...
    def GenerateReachForecast(
        self,
        request: global___GenerateReachForecastRequest,
    ) -> global___GenerateReachForecastResponse: ...

class ReachPlanServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ListPlannableLocations(
        self,
        request: global___ListPlannableLocationsRequest,
        context: grpc.ServicerContext,
    ) -> global___ListPlannableLocationsResponse: ...
    @abc.abstractmethod
    def ListPlannableProducts(
        self,
        request: global___ListPlannableProductsRequest,
        context: grpc.ServicerContext,
    ) -> global___ListPlannableProductsResponse: ...
    @abc.abstractmethod
    def GenerateProductMixIdeas(
        self,
        request: global___GenerateProductMixIdeasRequest,
        context: grpc.ServicerContext,
    ) -> global___GenerateProductMixIdeasResponse: ...
    @abc.abstractmethod
    def GenerateReachForecast(
        self,
        request: global___GenerateReachForecastRequest,
        context: grpc.ServicerContext,
    ) -> global___GenerateReachForecastResponse: ...

def add_ReachPlanServiceServicer_to_server(
    servicer: ReachPlanServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CallTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CallType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CallType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CallTypeEnum.CallType.V(0)
        UNKNOWN = CallTypeEnum.CallType.V(1)
        MANUALLY_DIALED = CallTypeEnum.CallType.V(2)
        HIGH_END_MOBILE_SEARCH = CallTypeEnum.CallType.V(3)
    class CallType(metaclass=_CallType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CallTypeEnum.CallType.V(0)
    UNKNOWN = CallTypeEnum.CallType.V(1)
    MANUALLY_DIALED = CallTypeEnum.CallType.V(2)
    HIGH_END_MOBILE_SEARCH = CallTypeEnum.CallType.V(3)
    def __init__(
        self,
    ) -> None: ...

global___CallTypeEnum = CallTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AccountBudgetProposalStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AccountBudgetProposalStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AccountBudgetProposalStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(0)
        UNKNOWN = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(1)
        PENDING = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(2)
        APPROVED_HELD = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(3)
        APPROVED = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(4)
        CANCELLED = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(5)
        REJECTED = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(6)
    class AccountBudgetProposalStatus(metaclass=_AccountBudgetProposalStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(0)
    UNKNOWN = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(1)
    PENDING = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(2)
    APPROVED_HELD = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(3)
    APPROVED = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(4)
    CANCELLED = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(5)
    REJECTED = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(6)
    def __init__(
        self,
    ) -> None: ...

global___AccountBudgetProposalStatusEnum = AccountBudgetProposalStatusEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.media_type_pb2
import google.ads.google_ads.v4.proto.enums.mime_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MediaFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    MIME_TYPE_FIELD_NUMBER: builtins.int
    SOURCE_URL_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FILE_SIZE_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    MEDIA_BUNDLE_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    VIDEO_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    type: google.ads.google_ads.v4.proto.enums.media_type_pb2.MediaTypeEnum.MediaType.V = (
        ...
    )
    mime_type: google.ads.google_ads.v4.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = (
        ...
    )
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def source_url(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def file_size(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def image(self) -> global___MediaImage: ...
    @property
    def media_bundle(self) -> global___MediaBundle: ...
    @property
    def audio(self) -> global___MediaAudio: ...
    @property
    def video(self) -> global___MediaVideo: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        type: google.ads.google_ads.v4.proto.enums.media_type_pb2.MediaTypeEnum.MediaType.V = ...,
        mime_type: google.ads.google_ads.v4.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = ...,
        source_url: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        file_size: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        image: typing.Optional[global___MediaImage] = ...,
        media_bundle: typing.Optional[global___MediaBundle] = ...,
        audio: typing.Optional[global___MediaAudio] = ...,
        video: typing.Optional[global___MediaVideo] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "audio",
            b"audio",
            "file_size",
            b"file_size",
            "id",
            b"id",
            "image",
            b"image",
            "media_bundle",
            b"media_bundle",
            "mediatype",
            b"mediatype",
            "name",
            b"name",
            "source_url",
            b"source_url",
            "video",
            b"video",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "audio",
            b"audio",
            "file_size",
            b"file_size",
            "id",
            b"id",
            "image",
            b"image",
            "media_bundle",
            b"media_bundle",
            "mediatype",
            b"mediatype",
            "mime_type",
            b"mime_type",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "source_url",
            b"source_url",
            "type",
            b"type",
            "video",
            b"video",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["mediatype", b"mediatype"]
    ) -> typing_extensions.Literal["image", "media_bundle", "audio", "video"]: ...

global___MediaFile = MediaFile

class MediaImage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.wrappers_pb2.BytesValue: ...
    def __init__(
        self,
        *,
        data: typing.Optional[google.protobuf.wrappers_pb2.BytesValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["data", b"data"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["data", b"data"]
    ) -> None: ...

global___MediaImage = MediaImage

class MediaBundle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.wrappers_pb2.BytesValue: ...
    def __init__(
        self,
        *,
        data: typing.Optional[google.protobuf.wrappers_pb2.BytesValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["data", b"data"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["data", b"data"]
    ) -> None: ...

global___MediaBundle = MediaBundle

class MediaAudio(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AD_DURATION_MILLIS_FIELD_NUMBER: builtins.int
    @property
    def ad_duration_millis(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        ad_duration_millis: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "ad_duration_millis", b"ad_duration_millis"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ad_duration_millis", b"ad_duration_millis"
        ],
    ) -> None: ...

global___MediaAudio = MediaAudio

class MediaVideo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AD_DURATION_MILLIS_FIELD_NUMBER: builtins.int
    YOUTUBE_VIDEO_ID_FIELD_NUMBER: builtins.int
    ADVERTISING_ID_CODE_FIELD_NUMBER: builtins.int
    ISCI_CODE_FIELD_NUMBER: builtins.int
    @property
    def ad_duration_millis(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def youtube_video_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def advertising_id_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def isci_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        ad_duration_millis: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        youtube_video_id: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        advertising_id_code: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        isci_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "ad_duration_millis",
            b"ad_duration_millis",
            "advertising_id_code",
            b"advertising_id_code",
            "isci_code",
            b"isci_code",
            "youtube_video_id",
            b"youtube_video_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ad_duration_millis",
            b"ad_duration_millis",
            "advertising_id_code",
            b"advertising_id_code",
            "isci_code",
            b"isci_code",
            "youtube_video_id",
            b"youtube_video_id",
        ],
    ) -> None: ...

global___MediaVideo = MediaVideo



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CriterionCategoryChannelAvailabilityModeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CriterionCategoryChannelAvailabilityMode(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CriterionCategoryChannelAvailabilityMode.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
            0
        )
        UNKNOWN = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
            1
        )
        ALL_CHANNELS = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
            2
        )
        CHANNEL_TYPE_AND_ALL_SUBTYPES = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
            3
        )
        CHANNEL_TYPE_AND_SUBSET_SUBTYPES = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
            4
        )
    class CriterionCategoryChannelAvailabilityMode(
        metaclass=_CriterionCategoryChannelAvailabilityMode
    ):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
        0
    )
    UNKNOWN = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
        1
    )
    ALL_CHANNELS = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
        2
    )
    CHANNEL_TYPE_AND_ALL_SUBTYPES = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
        3
    )
    CHANNEL_TYPE_AND_SUBSET_SUBTYPES = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
        4
    )
    def __init__(
        self,
    ) -> None: ...

global___CriterionCategoryChannelAvailabilityModeEnum = (
    CriterionCategoryChannelAvailabilityModeEnum
)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.customer_label_pb2
import grpc

from .customer_label_service_pb2 import *

class CustomerLabelServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCustomerLabel(
        self,
        request: global___GetCustomerLabelRequest,
    ) -> google.ads.google_ads.v4.proto.resources.customer_label_pb2.CustomerLabel: ...
    def MutateCustomerLabels(
        self,
        request: global___MutateCustomerLabelsRequest,
    ) -> global___MutateCustomerLabelsResponse: ...

class CustomerLabelServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomerLabel(
        self,
        request: global___GetCustomerLabelRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.customer_label_pb2.CustomerLabel: ...
    @abc.abstractmethod
    def MutateCustomerLabels(
        self,
        request: global___MutateCustomerLabelsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCustomerLabelsResponse: ...

def add_CustomerLabelServiceServicer_to_server(
    servicer: CustomerLabelServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class LocationExtensionTargetingCriterionFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _LocationExtensionTargetingCriterionField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            LocationExtensionTargetingCriterionField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
            0
        )
        UNKNOWN = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
            1
        )
        ADDRESS_LINE_1 = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
            2
        )
        ADDRESS_LINE_2 = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
            3
        )
        CITY = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
            4
        )
        PROVINCE = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
            5
        )
        POSTAL_CODE = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
            6
        )
        COUNTRY_CODE = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
            7
        )
    class LocationExtensionTargetingCriterionField(
        metaclass=_LocationExtensionTargetingCriterionField
    ):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
        0
    )
    UNKNOWN = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
        1
    )
    ADDRESS_LINE_1 = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
        2
    )
    ADDRESS_LINE_2 = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
        3
    )
    CITY = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
        4
    )
    PROVINCE = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
        5
    )
    POSTAL_CODE = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
        6
    )
    COUNTRY_CODE = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
        7
    )
    def __init__(
        self,
    ) -> None: ...

global___LocationExtensionTargetingCriterionFieldEnum = (
    LocationExtensionTargetingCriterionFieldEnum
)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.account_budget_proposal_pb2
import grpc

from .account_budget_proposal_service_pb2 import *

class AccountBudgetProposalServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAccountBudgetProposal(
        self,
        request: global___GetAccountBudgetProposalRequest,
    ) -> google.ads.google_ads.v6.proto.resources.account_budget_proposal_pb2.AccountBudgetProposal: ...
    def MutateAccountBudgetProposal(
        self,
        request: global___MutateAccountBudgetProposalRequest,
    ) -> global___MutateAccountBudgetProposalResponse: ...

class AccountBudgetProposalServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAccountBudgetProposal(
        self,
        request: global___GetAccountBudgetProposalRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.account_budget_proposal_pb2.AccountBudgetProposal: ...
    @abc.abstractmethod
    def MutateAccountBudgetProposal(
        self,
        request: global___MutateAccountBudgetProposalRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAccountBudgetProposalResponse: ...

def add_AccountBudgetProposalServiceServicer_to_server(
    servicer: AccountBudgetProposalServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DisplayUploadProductTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _DisplayUploadProductType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            DisplayUploadProductType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(0)
        UNKNOWN = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(1)
        HTML5_UPLOAD_AD = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(2)
        DYNAMIC_HTML5_EDUCATION_AD = (
            DisplayUploadProductTypeEnum.DisplayUploadProductType.V(3)
        )
        DYNAMIC_HTML5_FLIGHT_AD = (
            DisplayUploadProductTypeEnum.DisplayUploadProductType.V(4)
        )
        DYNAMIC_HTML5_HOTEL_RENTAL_AD = (
            DisplayUploadProductTypeEnum.DisplayUploadProductType.V(5)
        )
        DYNAMIC_HTML5_JOB_AD = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(
            6
        )
        DYNAMIC_HTML5_LOCAL_AD = (
            DisplayUploadProductTypeEnum.DisplayUploadProductType.V(7)
        )
        DYNAMIC_HTML5_REAL_ESTATE_AD = (
            DisplayUploadProductTypeEnum.DisplayUploadProductType.V(8)
        )
        DYNAMIC_HTML5_CUSTOM_AD = (
            DisplayUploadProductTypeEnum.DisplayUploadProductType.V(9)
        )
        DYNAMIC_HTML5_TRAVEL_AD = (
            DisplayUploadProductTypeEnum.DisplayUploadProductType.V(10)
        )
        DYNAMIC_HTML5_HOTEL_AD = (
            DisplayUploadProductTypeEnum.DisplayUploadProductType.V(11)
        )
    class DisplayUploadProductType(metaclass=_DisplayUploadProductType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(0)
    UNKNOWN = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(1)
    HTML5_UPLOAD_AD = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(2)
    DYNAMIC_HTML5_EDUCATION_AD = (
        DisplayUploadProductTypeEnum.DisplayUploadProductType.V(3)
    )
    DYNAMIC_HTML5_FLIGHT_AD = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(4)
    DYNAMIC_HTML5_HOTEL_RENTAL_AD = (
        DisplayUploadProductTypeEnum.DisplayUploadProductType.V(5)
    )
    DYNAMIC_HTML5_JOB_AD = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(6)
    DYNAMIC_HTML5_LOCAL_AD = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(7)
    DYNAMIC_HTML5_REAL_ESTATE_AD = (
        DisplayUploadProductTypeEnum.DisplayUploadProductType.V(8)
    )
    DYNAMIC_HTML5_CUSTOM_AD = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(9)
    DYNAMIC_HTML5_TRAVEL_AD = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(
        10
    )
    DYNAMIC_HTML5_HOTEL_AD = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(11)
    def __init__(
        self,
    ) -> None: ...

global___DisplayUploadProductTypeEnum = DisplayUploadProductTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class KeywordPlanAdGroupKeywordErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _KeywordPlanAdGroupKeywordError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            KeywordPlanAdGroupKeywordError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V(0)
        )
        UNKNOWN = KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V(1)
        INVALID_KEYWORD_MATCH_TYPE = (
            KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V(2)
        )
        DUPLICATE_KEYWORD = (
            KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V(3)
        )
        KEYWORD_TEXT_TOO_LONG = (
            KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V(4)
        )
        KEYWORD_HAS_INVALID_CHARS = (
            KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V(5)
        )
        KEYWORD_HAS_TOO_MANY_WORDS = (
            KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V(6)
        )
        INVALID_KEYWORD_TEXT = (
            KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V(7)
        )
        NEGATIVE_KEYWORD_HAS_CPC_BID = (
            KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V(8)
        )
    class KeywordPlanAdGroupKeywordError(metaclass=_KeywordPlanAdGroupKeywordError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V(0)
    UNKNOWN = KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V(1)
    INVALID_KEYWORD_MATCH_TYPE = (
        KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V(2)
    )
    DUPLICATE_KEYWORD = (
        KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V(3)
    )
    KEYWORD_TEXT_TOO_LONG = (
        KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V(4)
    )
    KEYWORD_HAS_INVALID_CHARS = (
        KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V(5)
    )
    KEYWORD_HAS_TOO_MANY_WORDS = (
        KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V(6)
    )
    INVALID_KEYWORD_TEXT = (
        KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V(7)
    )
    NEGATIVE_KEYWORD_HAS_CPC_BID = (
        KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V(8)
    )
    def __init__(
        self,
    ) -> None: ...

global___KeywordPlanAdGroupKeywordErrorEnum = KeywordPlanAdGroupKeywordErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.customer_user_access_invitation_pb2
import grpc

from .customer_user_access_invitation_service_pb2 import *

class CustomerUserAccessInvitationServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCustomerUserAccessInvitation(
        self,
        request: global___GetCustomerUserAccessInvitationRequest,
    ) -> google.ads.google_ads.v6.proto.resources.customer_user_access_invitation_pb2.CustomerUserAccessInvitation: ...
    def MutateCustomerUserAccessInvitation(
        self,
        request: global___MutateCustomerUserAccessInvitationRequest,
    ) -> global___MutateCustomerUserAccessInvitationResponse: ...

class CustomerUserAccessInvitationServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomerUserAccessInvitation(
        self,
        request: global___GetCustomerUserAccessInvitationRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.customer_user_access_invitation_pb2.CustomerUserAccessInvitation: ...
    @abc.abstractmethod
    def MutateCustomerUserAccessInvitation(
        self,
        request: global___MutateCustomerUserAccessInvitationRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCustomerUserAccessInvitationResponse: ...

def add_CustomerUserAccessInvitationServiceServicer_to_server(
    servicer: CustomerUserAccessInvitationServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.resources.account_link_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GetAccountLinkRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetAccountLinkRequest = GetAccountLinkRequest

class CreateAccountLinkRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_LINK_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    @property
    def account_link(
        self,
    ) -> google.ads.google_ads.v5.proto.resources.account_link_pb2.AccountLink: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        account_link: typing.Optional[
            google.ads.google_ads.v5.proto.resources.account_link_pb2.AccountLink
        ] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["account_link", b"account_link"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "account_link", b"account_link", "customer_id", b"customer_id"
        ],
    ) -> None: ...

global___CreateAccountLinkRequest = CreateAccountLinkRequest

class CreateAccountLinkResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___CreateAccountLinkResponse = CreateAccountLinkResponse

class MutateAccountLinkRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    PARTIAL_FAILURE_FIELD_NUMBER: builtins.int
    VALIDATE_ONLY_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    partial_failure: builtins.bool = ...
    validate_only: builtins.bool = ...
    @property
    def operation(self) -> global___AccountLinkOperation: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        operation: typing.Optional[global___AccountLinkOperation] = ...,
        partial_failure: builtins.bool = ...,
        validate_only: builtins.bool = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["operation", b"operation"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id",
            b"customer_id",
            "operation",
            b"operation",
            "partial_failure",
            b"partial_failure",
            "validate_only",
            b"validate_only",
        ],
    ) -> None: ...

global___MutateAccountLinkRequest = MutateAccountLinkRequest

class AccountLinkOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REMOVE_FIELD_NUMBER: builtins.int
    remove: typing.Text = ...
    def __init__(
        self,
        *,
        remove: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "operation", b"operation", "remove", b"remove"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "operation", b"operation", "remove", b"remove"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["operation", b"operation"]
    ) -> typing_extensions.Literal["remove"]: ...

global___AccountLinkOperation = AccountLinkOperation

class MutateAccountLinkResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULT_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> global___MutateAccountLinkResult: ...
    def __init__(
        self,
        *,
        result: typing.Optional[global___MutateAccountLinkResult] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["result", b"result"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["result", b"result"]
    ) -> None: ...

global___MutateAccountLinkResponse = MutateAccountLinkResponse

class MutateAccountLinkResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___MutateAccountLinkResult = MutateAccountLinkResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FrequencyCapTimeUnitEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FrequencyCapTimeUnit(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FrequencyCapTimeUnit.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(0)
        UNKNOWN = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(1)
        DAY = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(2)
        WEEK = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(3)
        MONTH = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(4)
    class FrequencyCapTimeUnit(metaclass=_FrequencyCapTimeUnit):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(0)
    UNKNOWN = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(1)
    DAY = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(2)
    WEEK = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(3)
    MONTH = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(4)
    def __init__(
        self,
    ) -> None: ...

global___FrequencyCapTimeUnitEnum = FrequencyCapTimeUnitEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FlightPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FlightPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FlightPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(0)
        UNKNOWN = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(1)
        DESTINATION_ID = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(2)
        ORIGIN_ID = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(3)
        FLIGHT_DESCRIPTION = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(4)
        ORIGIN_NAME = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(5)
        DESTINATION_NAME = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(6)
        FLIGHT_PRICE = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(7)
        FORMATTED_PRICE = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(8)
        FLIGHT_SALE_PRICE = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(9)
        FORMATTED_SALE_PRICE = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(10)
        IMAGE_URL = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(11)
        FINAL_URLS = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(12)
        FINAL_MOBILE_URLS = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(13)
        TRACKING_URL = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(14)
        ANDROID_APP_LINK = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(15)
        SIMILAR_DESTINATION_IDS = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(
            16
        )
        IOS_APP_LINK = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(17)
        IOS_APP_STORE_ID = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(18)
    class FlightPlaceholderField(metaclass=_FlightPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(0)
    UNKNOWN = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(1)
    DESTINATION_ID = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(2)
    ORIGIN_ID = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(3)
    FLIGHT_DESCRIPTION = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(4)
    ORIGIN_NAME = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(5)
    DESTINATION_NAME = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(6)
    FLIGHT_PRICE = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(7)
    FORMATTED_PRICE = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(8)
    FLIGHT_SALE_PRICE = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(9)
    FORMATTED_SALE_PRICE = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(10)
    IMAGE_URL = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(11)
    FINAL_URLS = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(12)
    FINAL_MOBILE_URLS = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(13)
    TRACKING_URL = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(14)
    ANDROID_APP_LINK = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(15)
    SIMILAR_DESTINATION_IDS = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(16)
    IOS_APP_LINK = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(17)
    IOS_APP_STORE_ID = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(18)
    def __init__(
        self,
    ) -> None: ...

global___FlightPlaceholderFieldEnum = FlightPlaceholderFieldEnum
